@@ -3,7 +3,6 @@
 Retrieve a value from the Sym Flow config.
 """
 
-import sys
 
 import click
 
@@ -16,7 +15,10 @@ from sym.flow.cli.helpers.global_options import GlobalOptions
 @click.make_pass_decorator(GlobalOptions, ensure=True)
 @click.argument("key")
 def config_get(options: GlobalOptions, key: str) -> None:
-    """Get a config value from your local Sym Flow config file"""
+    """Get a config value from your local Sym Flow config file.
+    Nested configs can be accessed by a dot-separated path
+    e.g. `symflow config get auth_token.access_token`
+    """
     # For internal use only
     try:
         value = Config.get_value(key)
