@@ -1,5 +1,6 @@
 import click
-from sym.cli.helpers.global_options import GlobalOptions
+
+from sym.flow.cli.helpers.global_options import GlobalOptions
 
 from ...helpers.debug import do_upload_terraform_output
 
