@@ -1,16 +1,18 @@
 import sys
+from typing import TYPE_CHECKING, cast
 
 import click
 import requests
 import validators
 
-import sym.flow.cli.helpers.cli as cli_helpers
-from sym.flow.cli.errors import SymAPIRequestError
-from sym.flow.cli.helpers.api import SymAPI
 from sym.flow.cli.helpers.config import Config, store_login_config
 from sym.flow.cli.helpers.global_options import GlobalOptions
+from sym.flow.cli.helpers.jwt import JWT
 from sym.flow.cli.helpers.login.login_flow import LoginFlow
 
+if TYPE_CHECKING:
+    from sym.flow.cli.helpers.login.login_flow import BrowserRedirectFlow
+
 
 def validate_email(ctx, param, value):
     """Returns value if the email address is valid, raises otherwise."""
@@ -31,61 +33,58 @@ def validate_email(ctx, param, value):
     default=11001,
 )
 @click.option(
-    "--email",
-    callback=validate_email,
+    "--org-slug",
     prompt=True,
-    default=lambda: Config.get_email() if Config.is_logged_in() else None,
+    default=lambda: Config.get_org().slug if Config.is_logged_in() else None,
 )
-def login(options: GlobalOptions, browser: bool, port: int, email: str) -> None:
+def login(options: GlobalOptions, browser: bool, port: int, org_slug: str) -> None:
     """Log in to your Sym account to authenticate with the Sym API. This is required to enable privileged actions within your Organization such as authoring Sym Flows or installing the Slack App.
 
     \b
     Example:
-        `symflow login --email user@symops.io`
+        `symflow login --org-slug sym`
     """
-    api = SymAPI(url=options.api_url)
-    org = api.get_organization_from_email(email)
-    if options.debug:
-        click.echo("Org: {slug} ({client_id})\n".format(**org))
-    else:
-        click.echo("Org: {slug}\n".format(**org))
+    if options.access_token:
+        click.secho("SYM_JWT is set, unset SYM_JWT to log in as a regular user", fg="red")
+        sys.exit(1)
 
-    flow = LoginFlow.get_login_flow(email, browser, port)
+    org = options.sym_api.get_organization_from_slug(org_slug)
+    flow = LoginFlow.get_login_flow(browser, port)
 
     if browser:
-        (url, *_) = flow.gen_browser_login_params(options, org)
-        styled_url = click.style(requests.utils.requote_uri(url), bold=True)
+        (url, *_) = cast("BrowserRedirectFlow", flow).gen_browser_login_params(
+            options, org
+        )
+        styled_url = click.style(requests.utils.requote_uri(url), bold=True)  # type: ignore
         click.echo(
             f"Opening the login page in your browser. If this doesn't work, please visit the following URL:\n"
             f"{styled_url}\n"
         )
 
-    auth_token = flow.login(options, org)
-    api.set_access_token(auth_token.get("access_token"))
-    fail_msg = "Sym could not verify this login. Please try again, or visit https://docs.symops.com/docs/login-sym-flow for more details."
+    # It's possible to not get an auth_token AND not have raised an exception before getting here
+    # if the user has just signed up.
+    if auth_token := flow.login(options, org):
+        options.set_access_token(auth_token["access_token"])
+        options.dprint(auth_token=auth_token)
+        click.echo("Login succeeded")
 
-    try:
-        is_logged_in = api.verify_login(email)
-    except SymAPIRequestError:
-        click.echo("A server error has occurred. Please try again later.")
-        return
-
-    if not is_logged_in:
-        click.echo(fail_msg)
-        return
-
-    options.dprint(auth_token=auth_token)
-    click.echo("Login succeeded")
-
-    store_login_config(email, org, auth_token)
+        jwt = JWT.from_access_token(auth_token["access_token"])
+        store_login_config(jwt.email, org, auth_token)
 
 
 @click.command(short_help="Log out of your Sym account")
 @click.make_pass_decorator(GlobalOptions, ensure=True)
 def logout(options: GlobalOptions) -> None:
+    if not Config.is_logged_in() and not options.access_token:
+        click.secho("✖ You are already logged out!", fg="red")
+        sys.exit(1)
+
+    if options.access_token:
+        click.secho(
+            "✖ You are logged in via SYM_JWT, you must unset SYM_JWT manually", fg="red"
+        )
+        sys.exit(1)
+
     if Config.is_logged_in():
         Config.logout()
         click.secho("✔️  You successfully logged out!", fg="green")
-    else:
-        click.secho("✖ You are already logged out!", fg="red")
-        sys.exit(1)
