@@ -7,4 +7,4 @@ def test_config_get_org(click_setup, test_org, auth_token):
         store_login_config("foo@bar.com", test_org, auth_token)
         result = runner.invoke(click_command, ["config", "get", "org"])
 
-        assert result.stdout.strip() == test_org["slug"]
+        assert result.stdout.strip() == test_org.slug
